@@ -16,9 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -374,7 +372,7 @@ g_thread_create_full (GThreadFunc       func,
   thread = g_thread_new_internal (NULL, g_deprecated_thread_proxy,
                                   func, data, stack_size, error);
 
-  if (!joinable)
+  if (thread && !joinable)
     {
       thread->joinable = FALSE;
       g_thread_unref (thread);
@@ -403,14 +401,8 @@ g_once_init_enter_impl (volatile gsize *location)
  * as well, and GStaticMutex has been deprecated.
  *
  * Here is a version of our give_me_next_number() example using
- * a GStaticMutex.
- *
- * <example>
- *  <title>
- *   Using <structname>GStaticMutex</structname>
- *   to simplify thread-safe programming
- *  </title>
- *  <programlisting>
+ * a GStaticMutex:
+ * |[
  *   int
  *   give_me_next_number (void)
  *   {
@@ -418,14 +410,13 @@ g_once_init_enter_impl (volatile gsize *location)
  *     int ret_val;
  *     static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
  *
- *     g_static_mutex_lock (&amp;mutex);
+ *     g_static_mutex_lock (&mutex);
  *     ret_val = current_number = calc_next_number (current_number);
- *     g_static_mutex_unlock (&amp;mutex);
+ *     g_static_mutex_unlock (&mutex);
  *
  *     return ret_val;
  *   }
- *  </programlisting>
- * </example>
+ * ]|
  *
  * Sometimes you would like to dynamically create a mutex. If you don't
  * want to require prior calling to g_thread_init(), because your code
@@ -440,16 +431,15 @@ g_once_init_enter_impl (volatile gsize *location)
  * the following functions, as it is defined differently on different
  * platforms.
  *
- * All of the <function>g_static_mutex_*</function> functions apart
- * from <function>g_static_mutex_get_mutex</function> can also be used
- * even if g_thread_init() has not yet been called. Then they do
- * nothing, apart from <function>g_static_mutex_trylock</function>,
- * which does nothing but returning %TRUE.
+ * All of the g_static_mutex_* functions apart from
+ * g_static_mutex_get_mutex() can also be used even if g_thread_init()
+ * has not yet been called. Then they do nothing, apart from
+ * g_static_mutex_trylock() which does nothing but returning %TRUE.
  *
- * <note><para>All of the <function>g_static_mutex_*</function>
- * functions are actually macros. Apart from taking their addresses, you
- * can however use them as if they were functions.</para></note>
- **/
+ * All of the g_static_mutex_* functions are actually macros. Apart from
+ * taking their addresses, you can however use them as if they were
+ * functions.
+ */
 
 /**
  * G_STATIC_MUTEX_INIT:
@@ -587,8 +577,8 @@ g_static_mutex_get_mutex_impl (GStaticMutex* mutex)
  * a #GStaticMutex as a member of a structure and the structure is
  * freed, you should also free the #GStaticMutex.
  *
- * <note><para>Calling g_static_mutex_free() on a locked mutex may
- * result in undefined behaviour.</para></note>
+ * Calling g_static_mutex_free() on a locked mutex may result in
+ * undefined behaviour.
  *
  * Deprecated: 2.32: Use g_mutex_clear()
  */
@@ -630,11 +620,11 @@ g_static_mutex_free (GStaticMutex* mutex)
  * Even though #GStaticRecMutex is not opaque, it should only be used
  * with the following functions.
  *
- * All of the <function>g_static_rec_mutex_*</function> functions can
- * be used even if g_thread_init() has not been called. Then they do
- * nothing, apart from <function>g_static_rec_mutex_trylock</function>,
- * which does nothing but returning %TRUE.
- **/
+ * All of the g_static_rec_mutex_* functions can be used even if
+ * g_thread_init() has not been called. Then they do nothing, apart
+ * from g_static_rec_mutex_trylock(), which does nothing but returning
+ * %TRUE.
+ */
 
 /**
  * G_STATIC_REC_MUTEX_INIT:
@@ -864,12 +854,10 @@ g_static_rec_mutex_free (GStaticRecMutex *mutex)
  * lock can be used for protecting data that some portions of code only
  * read from, while others also write. In such situations it is
  * desirable that several readers can read at once, whereas of course
- * only one writer may write at a time. Take a look at the following
- * example:
+ * only one writer may write at a time.
  *
- * <example>
- *  <title>An array with access functions</title>
- *  <programlisting>
+ * Take a look at the following example:
+ * |[
  *   GStaticRWLock rwlock = G_STATIC_RW_LOCK_INIT;
  *   GPtrArray *array;
  *
@@ -881,10 +869,10 @@ g_static_rec_mutex_free (GStaticRecMutex *mutex)
  *     if (!array)
  *       return NULL;
  *
- *     g_static_rw_lock_reader_lock (&amp;rwlock);
- *     if (index &lt; array->len)
+ *     g_static_rw_lock_reader_lock (&rwlock);
+ *     if (index < array->len)
  *       retval = g_ptr_array_index (array, index);
- *     g_static_rw_lock_reader_unlock (&amp;rwlock);
+ *     g_static_rw_lock_reader_unlock (&rwlock);
  *
  *     return retval;
  *   }
@@ -892,27 +880,25 @@ g_static_rec_mutex_free (GStaticRecMutex *mutex)
  *   void
  *   my_array_set (guint index, gpointer data)
  *   {
- *     g_static_rw_lock_writer_lock (&amp;rwlock);
+ *     g_static_rw_lock_writer_lock (&rwlock);
  *
  *     if (!array)
- *       array = g_ptr_array_new (<!-- -->);
+ *       array = g_ptr_array_new ();
  *
  *     if (index >= array->len)
- *       g_ptr_array_set_size (array, index+1);
+ *       g_ptr_array_set_size (array, index + 1);
  *     g_ptr_array_index (array, index) = data;
  *
- *     g_static_rw_lock_writer_unlock (&amp;rwlock);
+ *     g_static_rw_lock_writer_unlock (&rwlock);
  *   }
- *  </programlisting>
- * </example>
+ * ]|
  *
  * This example shows an array which can be accessed by many readers
- * (the <function>my_array_get()</function> function) simultaneously,
- * whereas the writers (the <function>my_array_set()</function>
- * function) will only be allowed once at a time and only if no readers
- * currently access the array. This is because of the potentially
- * dangerous resizing of the array. Using these functions is fully
- * multi-thread safe now.
+ * (the my_array_get() function) simultaneously, whereas the writers
+ * (the my_array_set() function) will only be allowed once at a time
+ * and only if no readers currently access the array. This is because
+ * of the potentially dangerous resizing of the array. Using these
+ * functions is fully multi-thread safe now.
  *
  * Most of the time, writers should have precedence over readers. That
  * means, for this implementation, that as soon as a writer wants to
@@ -924,20 +910,18 @@ g_static_rec_mutex_free (GStaticRecMutex *mutex)
  * Even though #GStaticRWLock is not opaque, it should only be used
  * with the following functions.
  *
- * All of the <function>g_static_rw_lock_*</function> functions can be
- * used even if g_thread_init() has not been called. Then they do
- * nothing, apart from <function>g_static_rw_lock_*_trylock</function>,
- * which does nothing but returning %TRUE.
+ * All of the g_static_rw_lock_* functions can be used even if
+ * g_thread_init() has not been called. Then they do nothing, apart
+ * from g_static_rw_lock_*_trylock, which does nothing but returning %TRUE.
  *
- * <note><para>A read-write lock has a higher overhead than a mutex. For
- * example, both g_static_rw_lock_reader_lock() and
- * g_static_rw_lock_reader_unlock() have to lock and unlock a
- * #GStaticMutex, so it takes at least twice the time to lock and unlock
- * a #GStaticRWLock that it does to lock and unlock a #GStaticMutex. So
- * only data structures that are accessed by multiple readers, and which
- * keep the lock for a considerable time justify a #GStaticRWLock. The
- * above example most probably would fare better with a
- * #GStaticMutex.</para></note>
+ * A read-write lock has a higher overhead than a mutex. For example, both
+ * g_static_rw_lock_reader_lock() and g_static_rw_lock_reader_unlock() have
+ * to lock and unlock a #GStaticMutex, so it takes at least twice the time
+ * to lock and unlock a #GStaticRWLock that it does to lock and unlock a
+ * #GStaticMutex. So only data structures that are accessed by multiple
+ * readers, and which keep the lock for a considerable time justify a
+ * #GStaticRWLock. The above example most probably would fare better with a
+ * #GStaticMutex.
  *
  * Deprecated: 2.32: Use a #GRWLock instead
  **/
@@ -1029,7 +1013,7 @@ g_static_rw_lock_reader_lock (GStaticRWLock* lock)
 
 /**
  * g_static_rw_lock_reader_trylock:
- * @lock: a #GStaticRWLock to lock for reading.
+ * @lock: a #GStaticRWLock to lock for reading
  *
  * Tries to lock @lock for reading. If @lock is already locked for
  * writing by another thread or if another thread is already waiting to
@@ -1037,7 +1021,7 @@ g_static_rw_lock_reader_lock (GStaticRWLock* lock)
  * @lock for reading and returns %TRUE. This lock has to be unlocked by
  * g_static_rw_lock_reader_unlock().
  *
- * Returns: %TRUE, if @lock could be locked for reading.
+ * Returns: %TRUE, if @lock could be locked for reading
  *
  * Deprectated: 2.32: Use g_rw_lock_reader_trylock() instead
  */
@@ -1063,7 +1047,7 @@ g_static_rw_lock_reader_trylock (GStaticRWLock* lock)
 
 /**
  * g_static_rw_lock_reader_unlock:
- * @lock: a #GStaticRWLock to unlock after reading.
+ * @lock: a #GStaticRWLock to unlock after reading
  *
  * Unlocks @lock. If a thread waits to lock @lock for writing and all
  * locks for reading have been unlocked, the waiting thread is woken up
@@ -1088,7 +1072,7 @@ g_static_rw_lock_reader_unlock  (GStaticRWLock* lock)
 
 /**
  * g_static_rw_lock_writer_lock:
- * @lock: a #GStaticRWLock to lock for writing.
+ * @lock: a #GStaticRWLock to lock for writing
  *
  * Locks @lock for writing. If @lock is already locked for writing or
  * reading by other threads, this function will block until @lock is
@@ -1119,14 +1103,14 @@ g_static_rw_lock_writer_lock (GStaticRWLock* lock)
 
 /**
  * g_static_rw_lock_writer_trylock:
- * @lock: a #GStaticRWLock to lock for writing.
+ * @lock: a #GStaticRWLock to lock for writing
  *
  * Tries to lock @lock for writing. If @lock is already locked (for
  * either reading or writing) by another thread, it immediately returns
  * %FALSE. Otherwise it locks @lock for writing and returns %TRUE. This
  * lock has to be unlocked by g_static_rw_lock_writer_unlock().
  *
- * Returns: %TRUE, if @lock could be locked for writing.
+ * Returns: %TRUE, if @lock could be locked for writing
  *
  * Deprectated: 2.32: Use g_rw_lock_writer_trylock() instead
  */
@@ -1267,32 +1251,28 @@ GPrivate static_private_private = G_PRIVATE_INIT (g_static_private_cleanup);
  * A #GStaticPrivate works almost like a #GPrivate, but it has one
  * significant advantage. It doesn't need to be created at run-time
  * like a #GPrivate, but can be defined at compile-time. This is
- * similar to the difference between #GMutex and #GStaticMutex. Now
- * look at our <function>give_me_next_number()</function> example with
- * #GStaticPrivate:
+ * similar to the difference between #GMutex and #GStaticMutex.
  *
- * <example>
- *  <title>Using GStaticPrivate for per-thread data</title>
- *  <programlisting>
+ * Now look at our give_me_next_number() example with #GStaticPrivate:
+ * |[
  *   int
- *   give_me_next_number (<!-- -->)
+ *   give_me_next_number ()
  *   {
  *     static GStaticPrivate current_number_key = G_STATIC_PRIVATE_INIT;
- *     int *current_number = g_static_private_get (&amp;current_number_key);
+ *     int *current_number = g_static_private_get (&current_number_key);
  *
  *     if (!current_number)
  *       {
- *         current_number = g_new (int,1);
+ *         current_number = g_new (int, 1);
  *         *current_number = 0;
- *         g_static_private_set (&amp;current_number_key, current_number, g_free);
+ *         g_static_private_set (&current_number_key, current_number, g_free);
  *       }
  *
  *     *current_number = calc_next_number (*current_number);
  *
  *     return *current_number;
  *   }
- *  </programlisting>
- * </example>
+ * ]|
  */
 
 /**
@@ -1379,8 +1359,7 @@ g_static_private_get (GStaticPrivate *private_key)
  * will be inherited only by the main thread, i.e. the one that called
  * g_thread_init().
  *
- * <note><para>@notify is used quite differently from @destructor in
- * g_private_new().</para></note>
+ * @notify is used quite differently from @destructor in g_private_new().
  */
 void
 g_static_private_set (GStaticPrivate *private_key,
@@ -1563,6 +1542,7 @@ g_cond_free (GCond *cond)
  * and g_time_val_add() can be used.
  *
  * Returns: %TRUE if @cond was signalled, or %FALSE on timeout
+ *
  * Deprecated:2.32: Use g_cond_wait_until() instead.
  */
 gboolean
